@@ -1,5 +1,5 @@
 """Top-level package for MP3 Combine and Split."""
 
 __author__ = """Philip Roche"""
-__email__ = 'phil@philroche.net'
-__version__ = '0.0.1'
+__email__ = "phil@philroche.net"
+__version__ = "0.0.2"
